@@ -33,13 +33,6 @@ static int realtime_policy = SCHED_FIFO;
 
 #undef  _POSIX_SPIN_LOCKS
 
-#if defined(__ANDROID__)
-/* Missing from Android's pthread implementation, but the default values
- * for newly created threads corresponds to PTHREAD_INHERIT_SCHED */
-#define PTHREAD_INHERIT_SCHED 0
-#define pthread_attr_setinheritsched(x, y)
-#endif
-
 static unsigned max_sharing = 0;
 
 namespace ucommon {
@@ -92,7 +85,7 @@ static unsigned rwlock_indexing = 1;
 #ifdef  __PTH__
 static pth_key_t threadmap;
 #else
-#ifdef  _MSWINDOWS_
+#ifdef  _MSTHREADS_
 static DWORD threadmap;
 #else
 static pthread_key_t threadmap;
@@ -114,7 +107,7 @@ rwlock_entry::rwlock_entry() : ThreadLock()
     count = 0;
 }
 
-#if !defined(_MSWINDOWS_) && !defined(__PTH__)
+#if !defined(_MSTHREADS_) && !defined(__PTH__)
 Conditional::attribute Conditional::attr;
 #endif
 
@@ -312,7 +305,7 @@ void Semaphore::set(unsigned value)
     }
 }
 
-#ifdef  _MSWINDOWS_
+#ifdef  _MSTHREADS_
 
 bool Thread::equal(pthread_t t1, pthread_t t2)
 {
@@ -556,7 +549,7 @@ bool ConditionalAccess::waitSignal(struct timespec *ts)
     return waitSignal((timeout_t)(ts->tv_sec * 1000 + (ts->tv_nsec / 1000000l)));
 }
 
-#elif defined(_MSWINDOWS_)
+#elif defined(_MSTHREADS_)
 
 void ConditionalAccess::waitSignal(void)
 {
@@ -711,7 +704,7 @@ bool Thread::is_active(void)
 
 bool JoinableThread::is_active(void)
 {
-#ifdef  _MSWINDOWS_
+#ifdef  _MSTHREADS_
     return (running != INVALID_HANDLE_VALUE) && !joining;
 #else
     return running && !joining;
@@ -1277,13 +1270,13 @@ void Mutex::_unlock(void)
     pthread_mutex_unlock(&mlock);
 }
 
-#ifdef  _MSWINDOWS_
+#ifdef  _MSTHREADS_
 
 TimedEvent::TimedEvent() :
 Timer()
 {
     event = CreateEvent(NULL, FALSE, FALSE, NULL);
-    InitializeCriticalSection(&mutex);
+    InitializeCriticalSection((LPCRITICAL_SECTION)&mutex);
     set();
 }
 
@@ -1293,21 +1286,21 @@ TimedEvent::~TimedEvent()
         CloseHandle(event);
         event = INVALID_HANDLE_VALUE;
     }
-    DeleteCriticalSection(&mutex);
+    DeleteCriticalSection((LPCRITICAL_SECTION)&mutex);
 }
 
 TimedEvent::TimedEvent(timeout_t timeout) :
 Timer(timeout)
 {
     event = CreateEvent(NULL, FALSE, FALSE, NULL);
-    InitializeCriticalSection(&mutex);
+    InitializeCriticalSection((LPCRITICAL_SECTION)&mutex);
 }
 
 TimedEvent::TimedEvent(time_t timer) :
 Timer(timer)
 {
     event = CreateEvent(NULL, FALSE, FALSE, NULL);
-    InitializeCriticalSection(&mutex);
+    InitializeCriticalSection((LPCRITICAL_SECTION)&mutex);
 }
 
 void TimedEvent::signal(void)
@@ -1330,9 +1323,9 @@ bool TimedEvent::sync(void)
     if(!timeout)
         return false;
 
-    LeaveCriticalSection(&mutex);
+    LeaveCriticalSection((LPCRITICAL_SECTION)&mutex);
     result = WaitForSingleObject(event, timeout);
-    EnterCriticalSection(&mutex);
+    EnterCriticalSection((LPCRITICAL_SECTION)&mutex);
     if(result != WAIT_OBJECT_0)
         return true;
     return false;
@@ -1733,8 +1726,8 @@ void barrier::wait(void)
 
 LockedPointer::LockedPointer()
 {
-#ifdef  _MSWINDOWS_
-    InitializeCriticalSection(&mutex);
+#ifdef  _MSTHREADS__
+    InitializeCriticalSection((LPCRITICAL_SECTION)&mutex);
 #else
 #ifdef  __PTH__
     static pthread_mutex_t lock = PTH_MUTEX_INIT;
@@ -1806,7 +1799,7 @@ Thread::Thread(size_t size)
 {
     stack = size;
     priority = 0;
-#ifdef  _MSWINDOWS_
+#ifdef  _MSTHREADS_
     cancellor = INVALID_HANDLE_VALUE;
 #else
     cancellor = NULL;
@@ -1814,7 +1807,7 @@ Thread::Thread(size_t size)
     init();
 }
 
-#if defined(_MSWINDOWS_)
+#if defined(_MSTHREADS_)
 
 void Thread::setPriority(void)
 {
@@ -1869,7 +1862,7 @@ void Thread::setPriority(void) {}
 
 void Thread::concurrency(int level)
 {
-#if defined(HAVE_PTHREAD_SETCONCURRENCY) && !defined(_MSWINDOWS_)
+#if defined(HAVE_PTHREAD_SETCONCURRENCY) && !defined(_MSTHREADS_)
     pthread_setconcurrency(level);
 #endif
 }
@@ -1883,7 +1876,7 @@ void Thread::policy(int polid)
 
 JoinableThread::JoinableThread(size_t size)
 {
-#ifdef  _MSWINDOWS_
+#ifdef  _MSTHREADS_
     cancellor = INVALID_HANDLE_VALUE;
     running = INVALID_HANDLE_VALUE;
     joining = false;
@@ -1897,7 +1890,7 @@ JoinableThread::JoinableThread(size_t size)
 
 DetachedThread::DetachedThread(size_t size)
 {
-#ifdef  _MSWINDOWS_
+#ifdef  _MSTHREADS_
     cancellor = INVALID_HANDLE_VALUE;
 #else
     cancellor = NULL;
@@ -1920,7 +1913,7 @@ void Thread::sleep(timeout_t timeout)
     ts.tv_sec = timeout / 1000l;
     ts.tv_nsec = (timeout % 1000l) * 1000000l;
     pthread_delay_np(&ts);
-#elif defined(_MSWINDOWS_)
+#elif defined(_MSTHREADS_)
     ::Sleep(timeout);
 #else
     usleep(timeout * 1000);
@@ -1929,7 +1922,7 @@ void Thread::sleep(timeout_t timeout)
 
 void Thread::yield(void)
 {
-#if defined(_MSWINDOWS_)
+#if defined(_MSTHREADS_)
     SwitchToThread();
 #elif defined(__PTH__)
     pth_yield(NULL);
@@ -1962,7 +1955,7 @@ DetachedThread::~DetachedThread()
 }
 
 extern "C" {
-#ifdef  _MSWINDOWS_
+#ifdef  _MSTHREADS_
     static unsigned __stdcall exec_thread(void *obj) {
         assert(obj != NULL);
 
@@ -1986,7 +1979,7 @@ extern "C" {
 #endif
 }
 
-#ifdef  _MSWINDOWS_
+#ifdef  _MSTHREADS_
 void JoinableThread::start(int adj)
 {
     if(running != INVALID_HANDLE_VALUE)
@@ -2058,8 +2051,10 @@ void JoinableThread::start(int adj)
     pthread_attr_t attr;
     pthread_attr_init(&attr);
     pthread_attr_setdetachstate(&attr, PTHREAD_CREATE_JOINABLE);
+#if HAVE_PTHREAD_ATTR_SETINHRITSCHED
     pthread_attr_setinheritsched(&attr, PTHREAD_INHERIT_SCHED);
 #endif
+#endif
 // we typically use "stack 1" for min stack...
 #ifdef  PTHREAD_STACK_MIN
     if(stack && stack < PTHREAD_STACK_MIN)
@@ -2089,8 +2084,10 @@ void DetachedThread::start(int adj)
     pthread_attr_t attr;
     pthread_attr_init(&attr);
     pthread_attr_setdetachstate(&attr, PTHREAD_CREATE_DETACHED);
+#if HAVE_PTHREAD_ATTR_SETINHRITSCHED
     pthread_attr_setinheritsched(&attr, PTHREAD_INHERIT_SCHED);
 #endif
+#endif
 // we typically use "stack 1" for min stack...
 #ifdef  PTHREAD_STACK_MIN
     if(stack && stack < PTHREAD_STACK_MIN)
@@ -2229,7 +2226,7 @@ void Thread::map(void)
 #ifdef  __PTH__
     pth_key_setdata(threadmap, this);
 #else
-#ifdef  _MSWINDOWS_
+#ifdef  _MSTHREADS_
     TlsSetValue(threadmap, this);
 #else
     pthread_setspecific(threadmap, this);
@@ -2242,7 +2239,7 @@ Thread *Thread::get(void)
 #ifdef  __PTH__
     return (Thread *)pth_key_setdata(threadmap);
 #else
-#ifdef  _MSWINDOWS_
+#ifdef  _MSTHREADS_
     return (Thread *)TlsGetValue(threadmap);
 #else
     return (Thread *)pthread_getspecific(threadmap);
@@ -2260,7 +2257,7 @@ void Thread::init(void)
         pth_key_create(&threadmap, NULL);
         atexit(pthread_shutdown);
 #else
-#ifdef  _MSWINDOWS_
+#ifdef  _MSTHREADS_
         threadmap = TlsAlloc();
 #else
         pthread_key_create(&threadmap, NULL);
