@@ -86,7 +86,7 @@
 
 // see if we are building for or using extended stdc++ runtime library support
 
-#if defined(NEW_STDCPP) || defined(OLD_STDCPP)
+#if defined(__ANDROID__) || defined(NEW_STDCPP) || defined(OLD_STDCPP)
 #define _UCOMMON_EXTENDED_
 #endif
 
@@ -183,8 +183,19 @@ typedef int pid_t;
 #include <sys/stat.h>
 #include <io.h>
 
+// gcc c++11 support on mingw requires pthread support library
+#if (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ > 7)) && defined(_UCOMMON_EXTENDED_) 
+#include <pthread.h>   // gnu libstdc++ now requires a win pthread
+#ifdef OLD_STDCPP
+#undef OLD_STDCPP
+#define NEW_STDCPP
+#endif
+#undef  _MSCONDITIONALS_
+#else   
+#define _MSTHREADS_
 typedef DWORD pthread_t;
 typedef CRITICAL_SECTION pthread_mutex_t;
+#endif
 typedef char *caddr_t;
 typedef HANDLE fd_t;
 typedef SOCKET socket_t;
@@ -205,6 +216,7 @@ extern "C" {
 
     typedef LPSERVICE_MAIN_FUNCTION cpr_service_t;
 
+#ifdef _MSTHREADS_
     inline void pthread_exit(void *p)
         {_endthreadex((DWORD)0);}
 
@@ -222,6 +234,7 @@ extern "C" {
 
     inline void pthread_mutex_unlock(pthread_mutex_t *mutex)
         {LeaveCriticalSection(mutex);}
+#endif
 
     inline char *strdup(const char *s)
         {return _strdup(s);}
